Merge pull request #2353 from anttsov:patch-1

PiperOrigin-RevId: 261198930
diff --git a/googlemock/README.md b/googlemock/README.md
index 55c4b83..183fdb8 100644
--- a/googlemock/README.md
+++ b/googlemock/README.md
@@ -28,6 +28,13 @@
 -   does not use exceptions, and
 -   is easy to learn and use.
 
+Details and examples can be found here:
+
+*   [gMock for Dummies](docs/for_dummies.md)
+*   [Legacy gMock FAQ](docs/gmock_faq.md)
+*   [gMock Cookbook](docs/cook_book.md)
+*   [gMock Cheat Sheet](docs/cheat_sheet.md)
+
 Please note that code under scripts/generator/ is from the [cppclean
 project](http://code.google.com/p/cppclean/) and under the Apache
 License, which is different from Google Mock's license.
diff --git a/googlemock/scripts/upload.py b/googlemock/scripts/upload.py
index 4b57473..95239dc 100755
--- a/googlemock/scripts/upload.py
+++ b/googlemock/scripts/upload.py
@@ -631,7 +631,7 @@
         new_content: For text files, this is empty.  For binary files, this is
           the contents of the new file, since the diff output won't contain
           information to reconstruct the current file.
-        is_binary: True if the file is binary.
+        is_binary: True iff the file is binary.
         status: The status of the file.
     """
 
diff --git a/googletest/scripts/pump.py b/googletest/scripts/pump.py
index 7dfb87a..5efb653 100755
--- a/googletest/scripts/pump.py
+++ b/googletest/scripts/pump.py
@@ -161,7 +161,7 @@
 
 
 def StartsWith(lines, pos, string):
-  """Returns True if the given position in lines starts with 'string'."""
+  """Returns True iff the given position in lines starts with 'string'."""
 
   return lines[pos.line][pos.column:].startswith(string)
 
diff --git a/googletest/scripts/upload.py b/googletest/scripts/upload.py
index 8563e5f..c852e4c 100755
--- a/googletest/scripts/upload.py
+++ b/googletest/scripts/upload.py
@@ -631,7 +631,7 @@
         new_content: For text files, this is empty.  For binary files, this is
           the contents of the new file, since the diff output won't contain
           information to reconstruct the current file.
-        is_binary: True if the file is binary.
+        is_binary: True iff the file is binary.
         status: The status of the file.
     """
diff --git a/googletest/scripts/gen_gtest_pred_impl.py b/googletest/scripts/gen_gtest_pred_impl.py
index b00830d..b43efdf 100755
--- a/googletest/scripts/gen_gtest_pred_impl.py
+++ b/googletest/scripts/gen_gtest_pred_impl.py
@@ -540,10 +540,10 @@
     }
   }
 
   // true if the test function is expected to run to finish.
   static bool expected_to_finish_;
 
   // true if the test function did run to finish.
   static bool finished_;
 """ % DEFS
 
@@ -572,12 +572,12 @@
     """Returns the test for a predicate assertion macro.
 
     Args:
-      use_format:     true if the assertion is a *_PRED_FORMAT*.
-      use_assert:     true if the assertion is a ASSERT_*.
-      expect_failure: true if the assertion is expected to fail.
-      use_functor:    true if the first argument of the assertion is
+      use_format:     true iff the assertion is a *_PRED_FORMAT*.
+      use_assert:     true iff the assertion is a ASSERT_*.
+      expect_failure: true iff the assertion is expected to fail.
+      use_functor:    true iff the first argument of the assertion is
                       a functor (as opposed to a function)
-      use_user_type:  true if the predicate functor/function takes
+      use_user_type:  true iff the predicate functor/function takes
                       argument(s) of a user-defined type.
 
     Example:
@@ -540,10 +540,10 @@
   }
 
-  // true if the test function is expected to run to finish.
+  // true iff the test function is expected to run to finish.
   static bool expected_to_finish_;
 
@@ -540,10 +540,10 @@
   static bool expected_to_finish_;
 
-  // true if the test function did run to finish.
+  // true iff the test function did run to finish.
   static bool finished_;
 """ % DEFS